You are viewing a plain text version of this content. The canonical link for it is here.
Posted to notifications@libcloud.apache.org by to...@apache.org on 2019/06/28 17:25:51 UTC

[libcloud] 03/07: Prefix argument name with "ex_" since it's an extension argument.

This is an automated email from the ASF dual-hosted git repository.

tomaz pushed a commit to branch trunk
in repository https://gitbox.apache.org/repos/asf/libcloud.git

commit 1170e9c3d93276fd20986172acaea863e9e4dd69
Author: Tomaz Muraus <to...@tomaz.me>
AuthorDate: Fri Jun 28 19:07:28 2019 +0200

    Prefix argument name with "ex_" since it's an extension argument.
---
 libcloud/compute/drivers/maxihost.py | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/libcloud/compute/drivers/maxihost.py b/libcloud/compute/drivers/maxihost.py
index 8f3756b..1eab3c8 100644
--- a/libcloud/compute/drivers/maxihost.py
+++ b/libcloud/compute/drivers/maxihost.py
@@ -119,16 +119,16 @@ class MaxihostNodeDriver(NodeDriver):
                     driver=self, extra=extra)
         return node
 
-    def list_locations(self, available=True):
+    def list_locations(self, ex_available=True):
         """
         List locations
 
         If available is True, show only locations which are available
         """
         locations = []
         data = self.connection.request('/regions')
         for location in data.object['regions']:
-            if available:
+            if ex_available:
                 if location.get('available'):
                     locations.append(self._to_location(location))
             else:
@@ -119,16 +119,16 @@ class MaxihostNodeDriver(NodeDriver):
         List locations
 
-        If available is True, show only locations which are available
+        If ex_available is True, show only locations which are available.
         """
         locations = []